@@ -57,7 +57,7 @@ class AppletTag
   // Construct an applet tag object from a .class file and the user's
   // current directory.
   AppletTag (String code, String archives,
-                    List parameters, Dimension dimensions)
+	     List parameters, Dimension dimensions)
     throws MalformedURLException, IOException
   {
     // Calculate code.
@@ -74,9 +74,9 @@ class AppletTag
     else
       // documentbase is the current working directory.
       this.documentbase = new URL ("file", "",
-                                   System.getProperty("user.dir")
-                                   + File.separator
-                                   + codebase);
+				   System.getProperty("user.dir")
+				   + File.separator
+				   + codebase);
 
     archivesList = archives;
     // Parse archives.
@@ -89,14 +89,16 @@ class AppletTag
         StringTokenizer paramTokenizer =
           new StringTokenizer ((String) pairs.next(), ",");
         this.parameters.put (paramTokenizer.nextToken().trim(),
-                             paramTokenizer.nextToken().trim());
+			     paramTokenizer.nextToken().trim());
       }
+    this.parameters.put("width", Integer.toString(dimensions.width));
+    this.parameters.put("height", Integer.toString(dimensions.height));
     this.dimensions = dimensions;
   }
 
   // Construct an applet tag object from an HTML stream.
   AppletTag (StreamTokenizer tagTokenizer,
-                    URL documentbase)
+	     URL documentbase)
     throws IOException
   {
     this.documentbase = documentbase;
@@ -134,6 +136,8 @@ class AppletTag
               }
           }
       }
+    this.parameters.put("width", Integer.toString(dimensions.width));
+    this.parameters.put("height", Integer.toString(dimensions.height));
   }
 
   // Parse a case-sensitive element.
